/*
 * Created on 27.3.2006
 *
 */
package cz.muni.fi.pb138.demo.validation;

import java.io.File;
import java.io.IOException;

import javax.xml.XMLConstants;
import javax.xml.transform.stream.StreamSource;
import javax.xml.validation.Schema;
import javax.xml.validation.SchemaFactory;
import javax.xml.validation.Validator;

import org.xml.sax.SAXException;

public class ValidatorDemo {

    private String schemaLanguage;

    private SchemaFactory factory;

    public ValidatorDemo(String sl) {
        //      specify the schema language
        schemaLanguage = sl;
        //      create a SchemaFactory capable of understanding WXS schemas
        factory = SchemaFactory.newInstance(schemaLanguage);
    }

    /**
     * @param args
     */
    public static void main(String[] args) {
        
        long startTime = System.currentTimeMillis();

        ValidatorDemo demo = new ValidatorDemo(
                XMLConstants.W3C_XML_SCHEMA_NS_URI);

        File doc = new File(args[0]);
        File schema = null;
        if (args.length > 1) {
            schema = new File(args[1]);
        }

        if (schema == null) {
            System.out
                    .println("Validating '"
                            + doc
                            + "' against the schema specified in the instance document");
        } else {
            System.out.println("Validating '" + doc + "' against '" + schema
                    + "'");
        }
        try {
            if (schema == null) {
                demo.validate(doc);
            } else {
                demo.validate(doc, schema);
            }
            System.out.println("Document is valid.");

        } catch (SAXException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        } catch (IOException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
        long endTime = System.currentTimeMillis();
        
        System.out.println("Validation finished in "+(endTime-startTime)+" ms.");
    }

    public void validate(File f, File schemaFile) throws SAXException,
            IOException {
        // load a WXS schema, represented by a Schema instance
        Schema schema = factory.newSchema(schemaFile);

        // create a Validator instance, which can be used to validate an instance document
        Validator validator = schema.newValidator();

        // validate the document
        validator.validate(new StreamSource(f));
    }

    public void validate(File f) throws SAXException, IOException {
        
        // use schema referred in the instance document 
        Schema schema = factory.newSchema();

        // create a Validator instance, which can be used to validate an instance document
        Validator validator = schema.newValidator();

        // validate the document
        validator.validate(new StreamSource(f));
    }

}
